<?php
/**
 * Default theme options.
 *
 * @package Onefold
 */

if ( ! function_exists( 'onefold_get_default_theme_options' ) ) :

	/**
	 * Get default theme options
	 *
	 * @since 1.0.0
	 *
	 * @return array Default theme options.
	 */
	function onefold_get_default_theme_options() {

		$defaults = array();

		// Header.
		$defaults['show_title']   = true;
		$defaults['show_tagline'] = false;

		// Layout.
		$defaults['global_layout']           = 'right-sidebar';
		$defaults['archive_layout']          = 'excerpt';
		$defaults['archive_image']           = 'large';
		$defaults['archive_image_alignment'] = 'center';
		$defaults['single_image']            = 'large';
		$defaults['single_image_alignment']  = 'center';

		// Home Page.
		$defaults['home_content_status'] = true;

		// Pagination.
		$defaults['pagination_type'] = 'numeric';

		// Content Meta.
		$defaults['show_meta_author']     = true;
		$defaults['show_meta_categories'] = true;
		$defaults['show_meta_tags']       = true;
		$defaults['show_meta_comment']    = true;

		// Footer.
		$defaults['copyright_text']        = esc_html__( 'Copyright &copy; [the-year] [the-site-link]. All rights reserved.', 'onefold-pro' );
		$defaults['powered_by_text']       = esc_html__( 'Onefold Pro by ', 'onefold-pro' ) . '<a target="_blank" rel="designer" href="https://wenthemes.com/">WEN Themes</a>';
		$defaults['reset_footer_content']  = false;
		$defaults['show_social_in_footer'] = false;
		$defaults['go_to_top']             = true;

		// Footer widgets.
		$defaults['enable_footer_widgets_background_image'] = false;
		$defaults['footer_widgets_background_image']        = '';

		// Blog.
		$defaults['excerpt_length']     = 40;
		$defaults['read_more_text']     = esc_html__( 'Read more', 'onefold-pro' );
		$defaults['exclude_categories'] = '';

		// Author Bio.
		$defaults['author_bio_in_single']           = true;
		$defaults['author_bio_show_recent_posts']   = false;
		$defaults['author_bio_recent_posts_number'] = 3;

		// Breadcrumb.
		$defaults['breadcrumb_type'] = 'simple';

		// Advanced.
		$defaults['custom_css'] = '';

		// Homepage Sections.
		$defaults['homepage_sections'] = 'services,portfolio,latest-news,testimonials,team,call-to-action,front-page-widgets';

		// Homepage Services.
		$defaults['services_title']  = esc_html__( 'Services', 'onefold-pro' );
		$defaults['services_number'] = 6;
		$defaults['services_column'] = 3;

		// Homepage Portfolio.
		$defaults['portfolio_title']            = esc_html__( 'Recent Works', 'onefold-pro' );
		$defaults['portfolio_category']         = 0;
		$defaults['portfolio_number']           = 6;
		$defaults['portfolio_column']           = 3;
		$defaults['portfolio_background_image'] = '';

		// Homepage Latest News.
		$defaults['latest_news_title']    = esc_html__( 'Latest News', 'onefold-pro' );
		$defaults['latest_news_category'] = 0;
		$defaults['latest_news_number']   = 4;
		$defaults['latest_news_column']   = 4;

		// Homepage Testimonials.
		$defaults['testimonials_title']            = esc_html__( 'Testimonials', 'onefold-pro' );
		$defaults['testimonials_category']         = 0;
		$defaults['testimonials_number']           = 4;
		$defaults['testimonials_background_image'] = '';

		// Homepage Team.
		$defaults['team_title']    = esc_html__( 'Our Team', 'onefold-pro' );
		$defaults['team_category'] = 0;
		$defaults['team_number']   = 4;
		$defaults['team_column']   = 4;

		// Homepage Call To Action.
		$defaults['cta_title']               = esc_html__( 'We are creative', 'onefold-pro' );
		$defaults['cta_subtitle']            = esc_html__( 'Art is not what you see, but what you make others see.', 'onefold-pro' );
		$defaults['cta_description']         = esc_html__( 'This is about you. Always be yourself, express yourself, have faith in yourself, do not go out and look for a successful personality and duplicate it.', 'onefold-pro' );
		$defaults['cta_primary_button_text'] = esc_html__( 'Learn more', 'onefold-pro' );
		$defaults['cta_primary_button_url']  = '#';
		$defaults['cta_secondary_button_text'] = esc_html__( 'Download', 'onefold-pro' );
		$defaults['cta_secondary_button_url']  = '#';

		// Font.
		$font_keys = onefold_get_font_family_theme_settings_options();
		if ( ! empty( $font_keys ) ) {
			foreach ( $font_keys as $k => $v ) {
			  $defaults[ $k ]  = $v['default'];
			}
		}
		$defaults['reset_font_settings'] = false;

		// Slider Options.
		$defaults['featured_slider_status']              = 'home-page';
		$defaults['featured_slider_transition_effect']   = 'fadeout';
		$defaults['featured_slider_transition_delay']    = 3;
		$defaults['featured_slider_transition_duration'] = 1;
		$defaults['featured_slider_enable_caption']      = true;
		$defaults['featured_slider_enable_arrow']        = true;
		$defaults['featured_slider_enable_pager']        = true;
		$defaults['featured_slider_enable_autoplay']     = true;
		$defaults['featured_slider_type']                = 'demo-slider';
		$defaults['featured_slider_number']              = 3;
		$defaults['featured_slider_category']            = '';
		$defaults['featured_slider_tag']                 = '';
		$defaults['featured_slider_read_more_text']      = esc_html__( 'Read More', 'onefold-pro' );

		// Color.
		$colors = onefold_get_default_colors();
		if ( ! empty( $colors ) ) {
		  foreach ( $colors as $key => $val ) {
		    $defaults[ $key ] = $val;
		  }
		}

		// Pass through filter.
		$defaults = apply_filters( 'onefold_filter_default_theme_options', $defaults );
		return $defaults;
	}

endif;
