<?php
/**
 * Helper functions related to customizer and options.
 *
 * @package Onefold
 */

if ( ! function_exists( 'onefold_get_global_layout_options' ) ) :

	/**
	 * Returns global layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function onefold_get_global_layout_options() {

		$choices = array(
			'left-sidebar'            => esc_html__( 'Primary Sidebar - Content', 'onefold-pro' ),
			'right-sidebar'           => esc_html__( 'Content - Primary Sidebar', 'onefold-pro' ),
			'three-columns'           => esc_html__( 'Three Columns ( Secondary - Content - Primary )', 'onefold-pro' ),
			'three-columns-pcs'       => esc_html__( 'Three Columns ( Primary - Content - Secondary )', 'onefold-pro' ),
			'three-columns-cps'       => esc_html__( 'Three Columns ( Content - Primary - Secondary )', 'onefold-pro' ),
			'three-columns-psc'       => esc_html__( 'Three Columns ( Primary - Secondary - Content )', 'onefold-pro' ),
			'three-columns-pcs-equal' => esc_html__( 'Three Columns ( Equal Primary - Content - Secondary )', 'onefold-pro' ),
			'three-columns-scp-equal' => esc_html__( 'Three Columns ( Equal Secondary - Content - Primary )', 'onefold-pro' ),
			'no-sidebar'              => esc_html__( 'No Sidebar', 'onefold-pro' ),
		);
		$output = apply_filters( 'onefold_filter_layout_options', $choices );
		return $output;

	}

endif;

if ( ! function_exists( 'onefold_get_pagination_type_options' ) ) :

	/**
	 * Returns pagination type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function onefold_get_pagination_type_options() {

		$choices = array(
			'default'               => esc_html__( 'Default (Older / Newer Post)', 'onefold-pro' ),
			'numeric'               => esc_html__( 'Numeric', 'onefold-pro' ),
			'infinite-scroll'       => esc_html__( 'Infinite Scroll - Scroll', 'onefold-pro' ),
			'infinite-scroll-click' => esc_html__( 'Infinite Scroll - Click', 'onefold-pro' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'onefold_get_breadcrumb_type_options' ) ) :

	/**
	 * Returns breadcrumb type options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function onefold_get_breadcrumb_type_options() {

		$choices = array(
			'disabled' => esc_html__( 'Disabled', 'onefold-pro' ),
			'simple'   => esc_html__( 'Simple', 'onefold-pro' ),
			'advanced' => esc_html__( 'Advanced', 'onefold-pro' ),
		);
		return $choices;

	}

endif;


if ( ! function_exists( 'onefold_get_archive_layout_options' ) ) :

	/**
	 * Returns archive layout options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function onefold_get_archive_layout_options() {

		$choices = array(
			'full'    => esc_html__( 'Full Post', 'onefold-pro' ),
			'excerpt' => esc_html__( 'Post Excerpt', 'onefold-pro' ),
		);
		$output = apply_filters( 'onefold_filter_archive_layout_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'onefold_get_image_sizes_options' ) ) :

	/**
	 * Returns image sizes options.
	 *
	 * @since 1.0.0
	 *
	 * @param bool  $add_disable True for adding No Image option.
	 * @param array $allowed Allowed image size options.
	 * @return array Image size options.
	 */
	function onefold_get_image_sizes_options( $add_disable = true, $allowed = array(), $show_dimension = true ) {

		global $_wp_additional_image_sizes;
		$get_intermediate_image_sizes = get_intermediate_image_sizes();
		$choices = array();
		if ( true === $add_disable ) {
			$choices['disable'] = esc_html__( 'No Image', 'onefold-pro' );
		}
		$choices['thumbnail'] = esc_html__( 'Thumbnail', 'onefold-pro' );
		$choices['medium']    = esc_html__( 'Medium', 'onefold-pro' );
		$choices['large']     = esc_html__( 'Large', 'onefold-pro' );
		$choices['full']      = esc_html__( 'Full (original)', 'onefold-pro' );

		if ( true === $show_dimension ) {
			foreach ( array( 'thumbnail', 'medium', 'large' ) as $key => $_size ) {
				$choices[ $_size ] = $choices[ $_size ] . ' (' . get_option( $_size . '_size_w' ) . 'x' . get_option( $_size . '_size_h' ) . ')';
			}
		}

		if ( ! empty( $_wp_additional_image_sizes ) && is_array( $_wp_additional_image_sizes ) ) {
			foreach ( $_wp_additional_image_sizes as $key => $size ) {
				$choices[ $key ] = $key;
				if ( true === $show_dimension ){
					$choices[ $key ] .= ' ('. $size['width'] . 'x' . $size['height'] . ')';
				}
			}
		}

		if ( ! empty( $allowed ) ) {
			foreach ( $choices as $key => $value ) {
				if ( ! in_array( $key, $allowed ) ) {
					unset( $choices[ $key ] );
				}
			}
		}

		return $choices;

	}

endif;


if ( ! function_exists( 'onefold_get_image_alignment_options' ) ) :

	/**
	 * Returns image options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function onefold_get_image_alignment_options() {

		$choices = array(
			'none'   => _x( 'None', 'Alignment', 'onefold-pro' ),
			'left'   => _x( 'Left', 'Alignment', 'onefold-pro' ),
			'center' => _x( 'Center', 'Alignment', 'onefold-pro' ),
			'right'  => _x( 'Right', 'Alignment', 'onefold-pro' ),
		);
		return $choices;

	}

endif;

if ( ! function_exists( 'onefold_get_featured_slider_transition_effects' ) ) :

	/**
	 * Returns the featured slider transition effects.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function onefold_get_featured_slider_transition_effects() {

		$choices = array(
			'fade'       => _x( 'fade', 'Transition Effect', 'onefold-pro' ),
			'fadeout'    => _x( 'fadeout', 'Transition Effect', 'onefold-pro' ),
			'none'       => _x( 'none', 'Transition Effect', 'onefold-pro' ),
			'scrollHorz' => _x( 'scrollHorz', 'Transition Effect', 'onefold-pro' ),
			'tileSlide'  => _x( 'tileSlide', 'Transition Effect', 'onefold-pro' ),
			'tileBlind'  => _x( 'tileBlind', 'Transition Effect', 'onefold-pro' ),
			'flipHorz'   => _x( 'flipHorz', 'Transition Effect', 'onefold-pro' ),
			'flipVert'   => _x( 'flipVert', 'Transition Effect', 'onefold-pro' ),
		);
		$output = apply_filters( 'onefold_filter_featured_slider_transition_effects', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'onefold_get_featured_slider_content_options' ) ) :

	/**
	 * Returns the featured slider content options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function onefold_get_featured_slider_content_options() {

		$choices = array(
			'home-page' => esc_html__( 'Static Front Page Only', 'onefold-pro' ),
			'disabled'  => esc_html__( 'Disabled', 'onefold-pro' ),
		);
		$output = apply_filters( 'onefold_filter_featured_slider_content_options', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if ( ! function_exists( 'onefold_get_featured_slider_type' ) ) :

	/**
	 * Returns the featured slider type.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function onefold_get_featured_slider_type() {

		$choices = array(
			'featured-page'     => __( 'Featured Pages', 'onefold-pro' ),
			'featured-category' => __( 'Featured Category', 'onefold-pro' ),
			'featured-post'     => __( 'Featured Posts', 'onefold-pro' ),
			'featured-image'    => __( 'Featured Images', 'onefold-pro' ),
			'featured-tag'      => __( 'Featured Tag', 'onefold-pro' ),
			'demo-slider'       => __( 'Demo Slider', 'onefold-pro' ),
		);
		$output = apply_filters( 'onefold_filter_featured_slider_type', $choices );
		if ( ! empty( $output ) ) {
			ksort( $output );
		}
		return $output;

	}

endif;

if( ! function_exists( 'onefold_get_customizer_font_options' ) ) :

	/**
	 * Returns customizer font options.
	 *
	 * @since 1.0.0
	 */
	function onefold_get_customizer_font_options(){

		$web_fonts = onefold_get_web_fonts();
		$os_fonts  = onefold_get_os_fonts();

		$web_fonts = array_merge( $web_fonts, $os_fonts );

		if ( ! empty( $web_fonts ) ) {
			ksort( $web_fonts );
		}

		$choices = array();

		if ( ! empty( $web_fonts ) ) {
			foreach ( $web_fonts as $k => $v ) {
				$choices[$k] = esc_html( $v['label'] );
			}
		}
		return $choices;

	}

endif;

if( ! function_exists( 'onefold_get_web_fonts' ) ) :

	/**
	 * Returns web font options.
	 *
	 * @since 1.0.0
	 */
	function onefold_get_web_fonts(){

		$choices = array(
			'philosopher' => array(
				'name'  => 'Philosopher',
				'label' => "'Philosopher', sans-serif",
				),
			'open-sans' => array(
				'name'  => 'Open Sans',
				'label' => "'Open Sans', sans-serif",
				),
			'pt-sans' => array(
				'name'  => 'PT Sans',
				'label' => "'PT Sans', sans-serif",
				),
			'merriweather-sans' => array(
				'name'  => 'Merriweather Sans',
				'label' => "'Merriweather Sans', sans-serif",
				),
			'roboto' => array(
				'name'  => 'Roboto',
				'label' => "'Roboto', sans-serif",
				),
			'arizonia' => array(
				'name'  => 'Arizonia',
				'label' => "'Arizonia', cursive",
				),
			'raleway' => array(
				'name'  => 'Raleway',
				'label' => "'Raleway', sans-serif",
				),
			'droid-sans' => array(
				'name'  => 'Droid Sans',
				'label' => "'Droid Sans', sans-serif",
				),
			'lato' => array(
				'name'  => 'Lato',
				'label' => "'Lato', sans-serif",
				),
			'dosis' => array(
				'name'  => 'Dosis',
				'label' => "'Dosis', sans-serif",
				),
			'slabo-27px' => array(
				'name'  => 'Slabo 27px',
				'label' => "'Slabo 27px', serif",
				),
			'oswald' => array(
				'name'  => 'Oswald',
				'label' => "'Oswald', sans-serif",
				),
			'pt-sans-narrow' => array(
				'name'  => 'PT Sans Narrow',
				'label' => "'PT Sans Narrow', sans-serif",
				),
			'josefin-slab' => array(
				'name'  => 'Josefin Slab',
				'label' => "'Josefin Slab', serif",
				),
			'alegreya' => array(
				'name'  => 'Alegreya',
				'label' => "'Alegreya', serif",
				),
			'exo' => array(
				'name'  => 'Exo',
				'label' => "'Exo', sans-serif",
				),
			'signika' => array(
				'name'  => 'Signika',
				'label' => "'Signika', sans-serif",
				),
			'lobster' => array(
				'name'  => 'Lobster',
				'label' => "'Lobster', cursive",
				),
			'indie-flower' => array(
				'name'  => 'Indie Flower',
				'label' => "'Indie Flower', cursive",
				),
			'shadows-into-light' => array(
				'name'  => 'Shadows Into Light',
				'label' => "'Shadows Into Light', cursive",
				),
			'kaushan-script' => array(
				'name'  => 'Kaushan Script',
				'label' => "'Kaushan Script', cursive",
				),
			'dancing-script' => array(
				'name'  => 'Dancing Script',
				'label' => "'Dancing Script', cursive",
				),
			'fredericka-the-great' => array(
				'name'  => 'Fredericka the Great',
				'label' => "'Fredericka the Great', cursive",
				),
			'covered-by-your-grace' => array(
				'name'  => 'Covered By Your Grace',
				'label' => "'Covered By Your Grace', cursive",
				),
			);
		$choices = apply_filters( 'onefold_filter_web_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}

		return $choices;

	}

endif;

if( ! function_exists( 'onefold_get_os_fonts' ) ) :

	/**
	 * Returns OS font options.
	 *
	 * @since 1.0.0
	 */
	function onefold_get_os_fonts(){

		$choices = array(
			'arial' => array(
				'name'  => 'Arial',
				'label' => "'Arial', sans-serif",
				),
			'georgia' => array(
				'name'  => 'Georgia',
				'label' => "'Georgia', serif",
				),
			'cambria' => array(
				'name'  => 'Cambria',
				'label' => "'Cambria', Georgia, serif",
				),
			'tahoma' => array(
				'name'  => 'Tahoma',
				'label' => "'Tahoma', Geneva, sans-serif",
				),
			'sans-serif' => array(
				'name'  => 'Sans Serif',
				'label' => "'Sans Serif', Arial",
				),
			'verdana' => array(
				'name'  => 'Verdana',
				'label' => "'Verdana', Geneva, sans-serif",
				),
			);
		$choices = apply_filters( 'onefold_filter_os_fonts', $choices );

		if ( ! empty( $choices ) ) {
			ksort( $choices );
		}
		return $choices;

	}

endif;

if( ! function_exists( 'onefold_get_font_family_from_key' ) ) :

	/**
	 * Return font family from font slug.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Font slug.
	 * @return string Font name.
	 */
	function onefold_get_font_family_from_key( $key ){

		$output = '';

		$web_fonts = onefold_get_web_fonts();
		$os_fonts  = onefold_get_os_fonts();

		$fonts = array_merge( $web_fonts, $os_fonts );

		if ( isset( $fonts[ $key ] ) ) {
			$output = $fonts[ $key ]['label'];
		}
		return $output;

	}

endif;

if( ! function_exists( 'onefold_get_font_family_theme_settings_options' ) ) :

	/**
	 * Returns font family theme settings options.
	 *
	 * @since 1.0.0
	 */
	function onefold_get_font_family_theme_settings_options(){

		$choices = array(
			'font_site_title' => array(
				'label'   => __( 'Site Title', 'onefold-pro' ),
				'default' => 'oswald',
				),
			'font_site_tagline' => array(
				'label'   => __( 'Site Tagline', 'onefold-pro' ),
				'default' => 'open-sans',
				),
			'font_site_default' => array(
				'label'   => __( 'Default', 'onefold-pro' ),
				'default' => 'open-sans',
				),

			'font_content_title' => array(
				'label'   => __( 'Content Title', 'onefold-pro' ),
				'default' => 'oswald',
				),
			'font_content_body' => array(
				'label'   => __( 'Content Body', 'onefold-pro' ),
				'default' => 'open-sans',
				),
			'font_heading_tags' => array(
				'label'   => __( 'Heading Tags', 'onefold-pro' ),
				'default' => 'open-sans',
				),
			'font_navigation' => array(
				'label'   => __( 'Navigation', 'onefold-pro' ),
				'default' => 'open-sans',
				),
			);
		return $choices;

	}

endif;

if( ! function_exists( 'onefold_get_default_colors' ) ) :

  /**
   * Returns default colors.
   *
   * @since 1.0.0
   *
   * @param string $scheme Color scheme.
   * @return array Color values based on scheme.
   */
	function onefold_get_default_colors( $scheme = 'default' ){

		$output = array();

		switch ( $scheme ) {

			case 'default':
			default:
			$output = array(
				// Basic.
				'color_basic_text'                    => '#727272',
				'color_basic_link'                    => '#e9c01e',
				'color_basic_link_hover'              => '#ffdf3d',
				'color_basic_heading'                 => '#222222',
				'color_basic_page_title'              => '#ffffff',
				'color_basic_button_background'       => '#e9c01e',
				'color_basic_button_text'             => '#ffffff',
				'color_basic_button_background_hover' => '#efcf2d',
				'color_basic_button_text_hover'       => '#ffffff',

				// Header.
				'color_header_background'                     => '#e9c01e',
				'color_header_title_background'               => '#e9c01e',
				'color_header_title'                          => '#ffffff',
				'color_header_title_hover'                    => '#ffffff',
				'color_header_tagline'                        => '#ffffff',

				// Primary Menu.
				'color_primary_menu_link'               	=> '#ffffff',
				'color_primary_menu_link_hover'          	=> '#e9c01e',
				'color_primary_submenu_background'     		=> '#e9c01e',

				// Slider.
				'color_slider_caption_background'       => '#e9c01e',
				'color_slider_caption_text'            => '#ffffff',
				'color_slider_caption_link'            => '#ffffff',
				'color_slider_caption_link_hover'      => '#ffffff',
				'color_slider_icon'                    => '#ffffff',
				'color_slider_icon_hover'              => '#ffffff',
				'color_slider_icon_background'         => '#000000',
				'color_slider_icon_background_hover'   => '#e9c01e',
				'color_slider_pager'                   => '#ffffff',
				'color_slider_pager_active'            => '#e9c01e',
				'color_slider_button'                  => '#ffffff',
				'color_slider_button_hover'            => '#ffffff',
				'color_slider_button_background'       => '#e9c01e',
				'color_slider_button_background_hover' => '#e9c01e',

				// Content.
				'color_content_background'     			=> '#ffffff',
				'color_primary_content_background'      => '#ffffff',
				'color_content_title'           		=> '#727272',
				'color_content_text'            		=> '#727272',
				'color_content_link'            		=> '#e9c01e',
				'color_content_link_hover'      		=> '#e9c01e',
				'color_content_meta_link'       		=> '#727272',
				'color_content_meta_link_hover' 		=> '#e9c01e',
				'color_content_meta_icon'       		=> '#727272',
				'color_content_meta_date'       		=> '#727272',
				'color_content_meta_date_month_background' 	=> '#e9c01e',
				'color_content_meta_date_day_background'    => '#727272',

				// Sidebar.
				'color_sidebar_widget_background'       => '#001837',
				'color_sidebar_title'      				=> '#001837',
				'color_sidebar_text'      				=> '#001837',
				'color_sidebar_link'       				=> '#001837',
				'color_sidebar_link_hover' 				=> '#e9c01e',
				'color_sidebar_list_icon'  				=> '#001837',

				// Home Page Widgets.
				'color_home_widgets_background' => '#ffffff',
				'color_home_widgets_title'      => '#222222',
				'color_home_widgets_text'       => '#727272',
				'color_home_widgets_link'       => '#e9c01e',
				'color_home_widgets_link_hover' => '#e9c01e',

				// CTA Section.
				'color_cta_section_background'              => '#4a4a4a',
				'color_cta_main_section_title'              => '#ffffff',
				'color_cta_section_text'                    => '#ffffff',
				'color_cta_section_button'                  => '#ffffff',
				'color_cta_section_button_hover'            => '#ffffff',
				'color_cta_section_button_background'       => '#e9c01e',
				'color_cta_section_button_background_hover' => '#efcf2d',

				// Portfolio  Section.
				'color_portfolio_section_background'    	=> '#4a4a4a',
				'color_portfolio_main_section_title'    	=> '#ffffff',
				'color_portfolio_section_title'         	=> '#ffffff',
				'color_portfolio_section_icon'          	=> '#ffffff',
				'color_portfolio_section_icon_background'   => '#e9c01e',



				// Section Testimonial.
				'color_testimonial_section_background'    => '#4a4a4a',
				'color_testimonial_main_section_title'    => '#ffffff',
				'color_testimonial_section_title' => '#ffffff',
				'color_testimonial_section_content'       => '#ffffff',
				'color_testimonial_pager'                => '#ffffff',
				'color_testimonial_section_pager_active'  => '#e9c01e',

				// Section Team.
				'color_team_section_background'       => '#ffffff',
				'color_team_main_section_title'       => '#222222',
				'color_team_section_title'            => '#ffffff',
				'color_team_section_title_background' => '#e9c01e',

				// Section Service.
				'color_service_section_background'    => '#ffffff',
				'color_service_main_section_title'    => '#222222',
				'color_service_section_title'         => '#ffffff',

				// Section Latest News.
				'color_latest_news_section_background'         => '#ffffff',
				'color_latest_news_main_section_title'         => '#222222',
				'color_latest_news_section_title'              => '#666666',
				'color_latest_news_section_title_hover'        => '#666666',
				'color_latest_news_section_content_background' => '#ffffff',
				'color_latest_news_section_meta_color'    	   => '#ffffff',
				'color_latest_news_section_meta_background'    => '#e9c01e',

				// Footer Widgets.
				'color_footer_widgets_background'			 => '#222222',
				'color_footer_widgets_title'     			 => '#ffffff',
				'color_footer_widgets_text'      			 => '#ffffff',
				'color_footer_widgets_link'      			 => '#ffffff',
				'color_footer_widgets_link_hover'			 => '#e9c01e',



				// Footer area.
				'color_footer_area_background' => '#000000',
				'color_footer_area_text'       => '#ffffff',
				'color_footer_area_link'       => '#e9c01e',
				'color_footer_area_link_hover' => '#e9c01e',

				// Go To Top.
				'color_goto_top_icon'             => '#ffffff',
				'color_goto_top_icon_hover'       => '#ffffff',
				'color_goto_top_background'       => '#e9c01e',
				'color_goto_top_background_hover' => '#e9c01e',

				// Pagination.
				'color_pagination_link'                  => '#fff',
				'color_pagination_link_hover'            => '#fff',
				'color_pagination_link_background'       => '#4fc3de',
				'color_pagination_link_background_hover' => '#e9c01e',

				// Breadcrumb.
				'color_breadcrumb_link'       => '#ffffff',
				'color_breadcrumb_link_hover' => '#4fc3de',
				'color_breadcrumb_text'       => '#e9c01e',



			);
			break;

		} // End switch.

	return $output;

	}

endif;


if( ! function_exists( 'onefold_get_color_theme_settings_options' ) ) :

  /**
   * Returns color theme settings options.
   *
   * @since 1.0.0
   */
  function onefold_get_color_theme_settings_options(){

  	$choices = array(

		// Basic.
  		'color_basic_text' => array(
  			'label'   => __( 'Text Color', 'onefold-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_link' => array(
  			'label'   => __( 'Link Color', 'onefold-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_heading' => array(
  			'label'   => __( 'Heading Color', 'onefold-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_page_title' => array(
  			'label'   => __( 'Page Title Color', 'onefold-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_text' => array(
  			'label'   => __( 'Button Text Color', 'onefold-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_background' => array(
  			'label'   => __( 'Button Background Color', 'onefold-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_text_hover' => array(
  			'label'   => __( 'Button Text Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_basic',
  			),
  		'color_basic_button_background_hover' => array(
  			'label'   => __( 'Button Background Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_basic',
  			),


		// Header.
  		'color_header_background' => array(
  			'label'   => __( 'Background Color', 'onefold-pro' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_title_background' => array(
  			'label'   => __( 'Site Title Background Color', 'onefold-pro' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_title' => array(
  			'label'   => __( 'Site Title Color', 'onefold-pro' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_title_hover' => array(
  			'label'   => __( 'Site Title Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_header',
  			),
  		'color_header_tagline' => array(
  			'label'   => __( 'Site Tagline Color', 'onefold-pro' ),
  			'section' => 'color_section_header',
  			),

		// Primary Menu.
  		'color_primary_menu_link' => array(
  			'label'   => __( 'Link Color', 'onefold-pro' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_menu_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_primary_menu',
  			),
  		'color_primary_submenu_background' => array(
  			'label'   => __( 'Submenu Background Color', 'onefold-pro' ),
  			'section' => 'color_section_primary_menu',
  			),


		// Content.
  		'color_content_background' => array(
  			'label'   => __( 'Background Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_primary_content_background' => array(
  			'label'   => __( 'Primary Content Background Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_title' => array(
  			'label'   => __( 'Title Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_text' => array(
  			'label'   => __( 'Text Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_link' => array(
  			'label'   => __( 'Link Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_link' => array(
  			'label'   => __( 'Meta Link Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_link_hover' => array(
  			'label'   => __( 'Meta Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_icon' => array(
  			'label'   => __( 'Meta Icon Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_date' => array(
  			'label'   => __( 'Meta Date Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_date_day_background' => array(
  			'label'   => __( 'Meta Day Background Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),
  		'color_content_meta_date_month_background' => array(
  			'label'   => __( 'Meta Month Background Color', 'onefold-pro' ),
  			'section' => 'color_section_content',
  			),

		// Slider.
  		'color_slider_caption_background' => array(
  			'label'   => __( 'Caption Background Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_caption_text' => array(
  			'label'   => __( 'Caption Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_caption_link' => array(
  			'label'   => __( 'Link Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_caption_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_icon' => array(
  			'label'   => __( 'Icon Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_icon_hover' => array(
  			'label'   => __( 'Icon Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_icon_background' => array(
  			'label'   => __( 'Icon Background Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_icon_background_hover' => array(
  			'label'   => __( 'Icon Background Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_pager' => array(
  			'label'   => __( 'Pager Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_pager_active' => array(
  			'label'   => __( 'Pager Active Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_button' => array(
  			'label'   => __( 'Button Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_button_hover' => array(
  			'label'   => __( 'Button Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_button_background' => array(
  			'label'   => __( 'Button Background Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),
  		'color_slider_button_background_hover' => array(
  			'label'   => __( 'Button Background Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_slider',
  			),

		// Home Page Widgets.
  		'color_home_widgets_background' => array(
  			'label'   => __( 'Widget Background Color', 'onefold-pro' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_title' => array(
  			'label'   => __( 'Widget Title Color', 'onefold-pro' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_text' => array(
  			'label'   => __( 'Text Color', 'onefold-pro' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_link' => array(
  			'label'   => __( 'Link Color', 'onefold-pro' ),
  			'section' => 'color_section_home_widgets',
  			),
  		'color_home_widgets_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_home_widgets',
  			),

		// Sidebar.
		'color_sidebar_widget_background' => array(
  			'label'   => __( 'Widget Background Color', 'onefold-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_title' => array(
  			'label'   => __( 'Title Color', 'onefold-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_text' => array(
  			'label'   => __( 'Text Color', 'onefold-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_link' => array(
  			'label'   => __( 'Link Color', 'onefold-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_sidebar',
		),
  		'color_sidebar_list_icon' => array(
  			'label'   => __( 'List Icon Color', 'onefold-pro' ),
  			'section' => 'color_section_sidebar',
		),

		// Footer area.
  		'color_footer_area_background' => array(
  			'label'   => __( 'Background Color', 'onefold-pro' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_text' => array(
  			'label'   => __( 'Text Color', 'onefold-pro' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_link' => array(
  			'label'   => __( 'Link Color', 'onefold-pro' ),
  			'section' => 'color_section_footer_area',
  			),
  		'color_footer_area_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_footer_area',
  			),

		// Go To Top.
  		'color_goto_top_icon' => array(
  			'label'   => __( 'Icon Color', 'onefold-pro' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_icon_hover' => array(
  			'label'   => __( 'Icon Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_background' => array(
  			'label'   => __( 'Background Color', 'onefold-pro' ),
  			'section' => 'color_section_goto_top',
  			),
  		'color_goto_top_background_hover' => array(
  			'label'   => __( 'Background Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_goto_top',
  			),

		// Pagination.
  		'color_pagination_link' => array(
  			'label'   => __( 'Link Color', 'onefold-pro' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_background' => array(
  			'label'   => __( 'Link Background Color', 'onefold-pro' ),
  			'section' => 'color_section_pagination',
  			),
  		'color_pagination_link_background_hover' => array(
  			'label'   => __( 'Link Background Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_pagination',
  			),

		// Breadcrumb.
  		'color_breadcrumb_link' => array(
  			'label'   => __( 'Link Color', 'onefold-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),
  		'color_breadcrumb_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),
  		'color_breadcrumb_text' => array(
  			'label'   => __( 'Text Color', 'onefold-pro' ),
  			'section' => 'color_section_breadcrumb',
  			),


  		//Specific section portfolio
  		'color_portfolio_section_background' => array(
  			'label'   => __( 'Section Background Color', 'onefold-pro' ),
  			'section' => 'color_section_portfolio_section',
  			),
  		'color_portfolio_main_section_title' => array(
  			'label'   => __( 'Main Section Title Color', 'onefold-pro' ),
  			'section' => 'color_section_portfolio_section',
  			),
  		'color_portfolio_section_title' => array(
  			'label'   => __( 'Title Color', 'onefold-pro' ),
  			'section' => 'color_section_portfolio_section',
  			),
  		'color_portfolio_section_icon' => array(
  			'label'   => __( 'Icon Color', 'onefold-pro' ),
  			'section' => 'color_section_portfolio_section',
  			),
  		'color_portfolio_section_icon_background' => array(
  			'label'   => __( 'Icon Background Color', 'onefold-pro' ),
  			'section' => 'color_section_portfolio_section',
  			),

  		// Specific section testimonial.

  		'color_testimonial_section_background' => array(
  			'label'   => __( 'Section Background Color', 'onefold-pro' ),
  			'section' => 'color_section_testimonial_section',
  			),
  		'color_testimonial_main_section_title' => array(
  			'label'   => __( 'Section Main Title Color', 'onefold-pro' ),
  			'section' => 'color_section_testimonial_section',
  			),
  		'color_testimonial_section_title' => array(
  			'label'   => __( 'Section Subtitle Color', 'onefold-pro' ),
  			'section' => 'color_section_testimonial_section',
  			),
  		'color_testimonial_section_content' => array(
  			'label'   => __( 'Content Color', 'onefold-pro' ),
  			'section' => 'color_section_testimonial_section',
  			),
  		'color_testimonial_pager' => array(
  			'label'   => __( 'Pager Color', 'onefold-pro' ),
  			'section' => 'color_section_testimonial_section',
  			),
  		'color_testimonial_section_pager_active' => array(
  			'label'   => __( 'Pager Active Color', 'onefold-pro' ),
  			'section' => 'color_section_testimonial_section',
  			),

  		// Specific section service.
  		'color_service_section_background' => array(
  			'label'   => __( 'Section Background Color', 'onefold-pro' ),
  			'section' => 'color_section_service_section',
  			),

  		'color_service_main_section_title' => array(
  			'label'   => __( 'Main Section Title Color', 'onefold-pro' ),
  			'section' => 'color_section_service_section',
  			),

  		'color_service_section_title' => array(
  			'label'   => __( 'Title Color', 'onefold-pro' ),
  			'section' => 'color_section_service_section',
  			),


  		// Specific section latest news.
  		'color_latest_news_section_background' => array(
  			'label'   => __( 'Section Background Color', 'onefold-pro' ),
  			'section' => 'color_section_latest_news_section',
  			),
  		'color_latest_news_main_section_title' => array(
  			'label'   => __( 'Main Section Title Color', 'onefold-pro' ),
  			'section' => 'color_section_latest_news_section',
  			),
  		'color_latest_news_section_title' => array(
  			'label'   => __( 'Title Color', 'onefold-pro' ),
  			'section' => 'color_section_latest_news_section',
  			),
  		'color_latest_news_section_title_hover' => array(
  			'label'   => __( 'Title Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_latest_news_section',
  			),
  		'color_latest_news_section_content_background' => array(
  			'label'   => __( 'Content Background Color', 'onefold-pro' ),
  			'section' => 'color_section_latest_news_section',
  			),
  		'color_latest_news_section_meta_color' => array(
  			'label'   => __( 'Content Meta Color', 'onefold-pro' ),
  			'section' => 'color_section_latest_news_section',
  			),
  		'color_latest_news_section_meta_background' => array(
  			'label'   => __( 'Content Meta Background Color', 'onefold-pro' ),
  			'section' => 'color_section_latest_news_section',
  			),


  		// Specific section CTA.
  		'color_cta_section_background' => array(
  			'label'   => __( 'Seciton Background Color', 'onefold-pro' ),
  			'section' => 'color_section_cta_section',
  			),
  		'color_cta_main_section_title' => array(
  			'label'   => __( 'Main Section Title Color', 'onefold-pro' ),
  			'section' => 'color_section_cta_section',
  			),
  		'color_cta_section_text' => array(
  			'label'   => __( 'Text Color', 'onefold-pro' ),
  			'section' => 'color_section_cta_section',
  			),
  		'color_cta_section_button' => array(
  			'label'   => __( 'Button Color', 'onefold-pro' ),
  			'section' => 'color_section_cta_section',
  			),
  		'color_cta_section_button_hover' => array(
  			'label'   => __( 'Button Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_cta_section',
  			),
  		'color_cta_section_button_background' => array(
  			'label'   => __( 'Button Background Color', 'onefold-pro' ),
  			'section' => 'color_section_cta_section',
  			),
  		'color_cta_section_button_background_hover' => array(
  			'label'   => __( 'Button Background Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_cta_section',
  			),


  		// Specific section team.
  		'color_team_section_background' => array(
  			'label'   => __( 'Section Background Color', 'onefold-pro' ),
  			'section' => 'color_section_team_section',
  			),
  		'color_team_main_section_title' => array(
  			'label'   => __( 'Main Section Title Color', 'onefold-pro' ),
  			'section' => 'color_section_team_section',
  			),
  		'color_team_section_title' => array(
  			'label'   => __( 'Title Color', 'onefold-pro' ),
  			'section' => 'color_section_team_section',
  			),

  		'color_team_section_title_background' => array(
  			'label'   => __( 'Title Background Color', 'onefold-pro' ),
  			'section' => 'color_section_team_section',
  			),
		// Footer widgets.
  		'color_footer_widgets_background' => array(
  			'label'   => __( 'Background Color', 'onefold-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_title' => array(
  			'label'   => __( 'Title Color', 'onefold-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_text' => array(
  			'label'   => __( 'Text Color', 'onefold-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_link' => array(
  			'label'   => __( 'Link Color', 'onefold-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),
  		'color_footer_widgets_link_hover' => array(
  			'label'   => __( 'Link Hover Color', 'onefold-pro' ),
  			'section' => 'color_section_footer_widgets',
  			),


  		);

    return $choices;

  }

endif;

if ( ! function_exists( 'onefold_get_color_panels_options' ) ) :

  /**
   * Returns color panels options.
   *
   * @since 1.0.0
   */
	function onefold_get_color_panels_options() {

		$choices = array(
			'color_panel_main' => array(
				'label' => __( 'Color Options', 'onefold-pro' ),
				),
			'color_panel_section' => array(
				'label' => __( 'Home Section Color Options', 'onefold-pro' ),
				),
			);
		return $choices;
	}

endif;
if ( ! function_exists( 'onefold_get_color_sections_options' ) ) :

  /**
   * Returns color sections options.
   *
   * @since 1.0.0
   */
	function onefold_get_color_sections_options() {

		$choices = array(
			'color_section_basic' => array(
				'label' => __( 'Basic Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_top_header' => array(
				'label' => __( 'Top Header Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_header' => array(
				'label' => __( 'Header Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_primary_menu' => array(
				'label' => __( 'Primary Menu Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_slider' => array(
				'label' => __( 'Slider Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_content' => array(
				'label' => __( 'Content Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_sidebar' => array(
				'label' => __( 'Sidebar Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_breadcrumb' => array(
				'label' => __( 'Breadcrumb Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_goto_top' => array(
				'label' => __( 'Go To Top Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_pagination' => array(
				'label' => __( 'Pagination Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_footer_widgets' => array(
				'label' => __( 'Footer Widgets Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_footer_bottom_widgets' => array(
				'label' => __( 'Footer Bottom Widgets Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_footer_area' => array(
				'label' => __( 'Footer Area Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_main',
				),
			'color_section_home_section' => array(
				'label' => __( 'Default Options', 'onefold-pro' ),
				'panel' => 'color_panel_section',
				),
			'color_section_testimonial_section' => array(
				'label' => __( 'Testimonial Section Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_section',
				),
			'color_section_service_section' => array(
				'label' => __( 'Service Section Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_section',
				),
			'color_section_latest_news_section' => array(
				'label' => __( 'Latest News Section Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_section',
				),
			'color_section_team_section' => array(
				'label' => __( 'Team Section Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_section',
				),
			'color_section_cta_section' => array(
				'label' => __( 'CTA Section Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_section',
				),
			'color_section_portfolio_section' => array(
				'label' => __( 'Portfolio Section Color Options', 'onefold-pro' ),
				'panel' => 'color_panel_section',
				),



			);
		return $choices;
	}

endif;

if ( ! function_exists( 'onefold_get_numbers_dropdown_options' ) ) :

	/**
	 * Returns numbers dropdown options.
	 *
	 * @since 1.0.0
	 *
	 * @param int $min Min.
	 * @param int $max Max.
	 *
	 * @return array Options array.
	 */
	function onefold_get_numbers_dropdown_options( $min = 1, $max = 4 ) {

		$output = array();

		if ( $min <= $max ) {
			for ( $i = $min; $i <= $max; $i++ ) {
				$output[ $i ] = $i;
			}
		}

		return $output;

	}

endif;

if ( ! function_exists( 'onefold_get_home_sections_options' ) ) :

	/**
	 * Returns home sections options.
	 *
	 * @since 1.0.0
	 *
	 * @return array Options array.
	 */
	function onefold_get_home_sections_options() {

		$choices = array(
			'services' => array(
				'label'    => __( 'Services', 'onefold-pro' ),
				'template' => 'template-parts/home/services',
				),
			'portfolio' => array(
				'label'    => __( 'Portfolio', 'onefold-pro' ),
				'template' => 'template-parts/home/portfolio',
				),
			'team' => array(
				'label'    => __( 'Team', 'onefold-pro' ),
				'template' => 'template-parts/home/team',
				),
			'testimonials' => array(
				'label'    => __( 'Testimonials', 'onefold-pro' ),
				'template' => 'template-parts/home/testimonials',
				),
			'call-to-action' => array(
				'label'    => __( 'Call To Action', 'onefold-pro' ),
				'template' => 'template-parts/home/call-to-action',
				),
			'latest-news' => array(
				'label'    => __( 'Latest News', 'onefold-pro' ),
				'template' => 'template-parts/home/latest-news',
				),
			'front-page-widgets' => array(
				'label'    => __( 'Front Page Widgets', 'onefold-pro' ),
				'template' => 'template-parts/home/front-page-widgets',
				),
			);
		$output = apply_filters( 'onefold_filter_home_sections_options', $choices );
		return $output;

	}

endif;

